'use strict'

const getStream = require('get-stream')
const fs = require('fs')
const pEvent = require('p-event')
const mkdirp = require('mkdirp')

const got = require('got')

const BINARY_CONTENT_TYPES = [
  'binary/octet-stream',
  'application/octet-stream',
  'application/x-binary'
]

const {
  YOUTUBE_DL_PATH,
  YOUTUBE_DL_HOST,
  YOUTUBE_DL_DIR,
  YOUTUBE_DL_FILENAME
} = require('./constants')

const download = async (url = YOUTUBE_DL_HOST) => {
  const stream = got.stream(url)
  const response = await pEvent(stream, 'response')
  const contentType = response.headers['content-type']
  let buffer, msg
  if (BINARY_CONTENT_TYPES.includes(contentType)) {
    buffer = await getStream(stream, { encoding: 'buffer' })
    msg = `Downloaded ${YOUTUBE_DL_FILENAME} from ${url} successfully!`
  } else {
    const [{ assets, tag_name: version }] = JSON.parse(await getStream(stream))
    const { browser_download_url: downloadUrl } = assets.find(
      ({ name }) => name === YOUTUBE_DL_FILENAME
    )
    buffer = got(downloadUrl).buffer()
    msg = version
  }
  const [fileData] = await Promise.all([buffer, mkdirp(YOUTUBE_DL_DIR)])
  fs.writeFileSync(YOUTUBE_DL_PATH, fileData, { mode: 493 })
  return msg
}

module.exports = download
