import Plugin from "./Plugin";
import type { GuildMember, StageChannel, TextChannel, VoiceChannel } from "discord.js";
/**
 * Custom Plugin
 * @extends Plugin
 * @abstract
 */
export declare abstract class CustomPlugin extends Plugin {
    type: "custom";
    abstract play(voiceChannel: VoiceChannel | StageChannel, url: string, member: GuildMember, textChannel: TextChannel | undefined, skip: boolean, unshift: boolean): Promise<void>;
}
/**
 * This method will be executed if the url is validated.
 * @param {Discord.VoiceChannel|Discord.StageChannel} voiceChannel The voice channel will be joined
 * @param {string} url Validated url
 * @param {Discord.GuildMember} member Requested user
 * @param {Discord.TextChannel?} textChannel Default {@link Queue#textChannel}
 * @param {boolean} skip Skip the playing song (if exists) and play the added song/playlist instantly
 * @param {boolean} unshift Add the song/playlist to the beginning of the queue (after the playing song if exists)
 * @returns {Promise<void>}
 * @method play
 * @memberof CustomPlugin#
 * @abstract
 */
export default CustomPlugin;
//# sourceMappingURL=CustomPlugin.d.ts.map